@@ -105,11 +105,15 @@ echo "curl --location --request GET "https://$CFD/pic.png" --cookie "Cookie: tok
 
 * There is currently my aws-cdk PR open for importing the Typescript Lambda@Edge interface https://github.com/aws/aws-cdk/pull/18836
 
+```bash
+git tag -a v2.16.0 -m "prepare tag version" && git push --tags
+```
+
 ## Thanks To
 
 * Crespo Wang for his pioneer work regarding private S3 assets https://javascript.plainenglish.io/use-lambda-edge-jwt-to-secure-s3-bucket-dcca6eec4d7e
 * As always to the amazing CDK / Projen Community. Join us on [Slack](https://cdk-dev.slack.com)!
-* [Projen](https://github.com/projen/projen) project and the community around it
+* [Projen](https://github.com/projen/projen) project and the community around it.
 * To you for checking this out. Check me out and perhaps give me feedback https://martinmueller.dev .
 
 I love to work on Content Management Open Source projects. A lot from my stuff you can already use on https://github.com/mmuller88 . If you like my work there and my blog posts, please consider supporting me on Patreon:
